@@ -1,10 +1,10 @@
 import asyncio
-from .pururin import get_pur
-from .nhentai import get_nh
-from .simplyh import get_sim
-from .hentaifox import get_hfox
-from .hentai2read import get_h2r
-from .utils.misc import choose
+from tomoe.pururin import get_pur
+from tomoe.nhentai import get_nh
+from tomoe.simplyh import get_sim
+from tomoe.hentaifox import get_hfox
+from tomoe.hentai2read import get_h2r
+from tomoe.utils.misc import choose
 
 
 class Tomoe():
